@@ -294,11 +294,11 @@ static gpointer vala_array_move_method_parent_class = NULL;
  */
 ValaArrayMoveMethod* vala_array_move_method_construct (GType object_type, ValaSourceReference* source_reference) {
 	ValaArrayMoveMethod* self;
-	ValaVoidType* _tmp0;
+	ValaVoidType* _tmp0_;
 	g_return_val_if_fail (source_reference != NULL, NULL);
-	_tmp0 = NULL;
-	self = (ValaArrayMoveMethod*) vala_method_construct (object_type, "move", (ValaDataType*) (_tmp0 = vala_void_type_new (NULL)), source_reference);
-	(_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL));
+	_tmp0_ = NULL;
+	self = (ValaArrayMoveMethod*) vala_method_construct (object_type, "move", (ValaDataType*) (_tmp0_ = vala_void_type_new (NULL)), source_reference);
+	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL));
 	vala_symbol_set_external ((ValaSymbol*) self, TRUE);
 	return self;
 }
