@@ -393,21 +393,21 @@ static gboolean vala_catch_clause_real_check (ValaCodeNode* base, ValaSemanticAn
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	if (vala_catch_clause_get_error_type (self) != NULL) {
-		ValaLocalVariable* _tmp2;
-		ValaDataType* _tmp1;
-		_tmp2 = NULL;
-		_tmp1 = NULL;
-		vala_catch_clause_set_error_variable (self, _tmp2 = vala_local_variable_new (_tmp1 = vala_data_type_copy (vala_catch_clause_get_error_type (self)), self->priv->_variable_name, NULL, NULL));
-		(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL));
-		(_tmp1 == NULL) ? NULL : (_tmp1 = (vala_code_node_unref (_tmp1), NULL));
+		ValaLocalVariable* _tmp2_;
+		ValaDataType* _tmp1_;
+		_tmp2_ = NULL;
+		_tmp1_ = NULL;
+		vala_catch_clause_set_error_variable (self, _tmp2_ = vala_local_variable_new (_tmp1_ = vala_data_type_copy (vala_catch_clause_get_error_type (self)), self->priv->_variable_name, NULL, NULL));
+		(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
+		(_tmp1_ == NULL) ? NULL : (_tmp1_ = (vala_code_node_unref (_tmp1_), NULL));
 		vala_scope_add (vala_symbol_get_scope ((ValaSymbol*) self->priv->_body), self->priv->_variable_name, (ValaSymbol*) self->priv->_error_variable);
 		vala_block_add_local_variable (self->priv->_body, self->priv->_error_variable);
 		vala_code_node_set_checked ((ValaCodeNode*) self->priv->_error_variable, TRUE);
 	} else {
-		ValaErrorType* _tmp3;
-		_tmp3 = NULL;
-		vala_catch_clause_set_error_type (self, (ValaDataType*) (_tmp3 = vala_error_type_new (NULL, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
-		(_tmp3 == NULL) ? NULL : (_tmp3 = (vala_code_node_unref (_tmp3), NULL));
+		ValaErrorType* _tmp3_;
+		_tmp3_ = NULL;
+		vala_catch_clause_set_error_type (self, (ValaDataType*) (_tmp3_ = vala_error_type_new (NULL, NULL, vala_code_node_get_source_reference ((ValaCodeNode*) self))));
+		(_tmp3_ == NULL) ? NULL : (_tmp3_ = (vala_code_node_unref (_tmp3_), NULL));
 	}
 	vala_code_node_check ((ValaCodeNode*) vala_catch_clause_get_error_type (self), analyzer);
 	vala_code_node_check ((ValaCodeNode*) self->priv->_body, analyzer);
@@ -432,12 +432,12 @@ ValaDataType* vala_catch_clause_get_error_type (ValaCatchClause* self) {
 
 
 void vala_catch_clause_set_error_type (ValaCatchClause* self, ValaDataType* value) {
-	ValaDataType* _tmp2;
-	ValaDataType* _tmp1;
+	ValaDataType* _tmp2_;
+	ValaDataType* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_data_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp2_);
 	if (self->priv->_data_type != NULL) {
 		vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_data_type, (ValaCodeNode*) self);
 	}
@@ -451,12 +451,12 @@ const char* vala_catch_clause_get_variable_name (ValaCatchClause* self) {
 
 
 void vala_catch_clause_set_variable_name (ValaCatchClause* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp2_;
+	const char* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_variable_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_variable_name = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_variable_name = (g_free (self->priv->_variable_name), NULL), _tmp2_);
 }
 
 
@@ -467,12 +467,12 @@ ValaBlock* vala_catch_clause_get_body (ValaCatchClause* self) {
 
 
 void vala_catch_clause_set_body (ValaCatchClause* self, ValaBlock* value) {
-	ValaBlock* _tmp2;
-	ValaBlock* _tmp1;
+	ValaBlock* _tmp2_;
+	ValaBlock* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_body = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_body == NULL) ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)), _tmp2_);
 }
 
 
@@ -483,12 +483,12 @@ ValaLocalVariable* vala_catch_clause_get_error_variable (ValaCatchClause* self)
 
 
 void vala_catch_clause_set_error_variable (ValaCatchClause* self, ValaLocalVariable* value) {
-	ValaLocalVariable* _tmp2;
-	ValaLocalVariable* _tmp1;
+	ValaLocalVariable* _tmp2_;
+	ValaLocalVariable* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_error_variable = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_error_variable == NULL) ? NULL : (self->priv->_error_variable = (vala_code_node_unref (self->priv->_error_variable), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_error_variable = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_error_variable == NULL) ? NULL : (self->priv->_error_variable = (vala_code_node_unref (self->priv->_error_variable), NULL)), _tmp2_);
 }
 
 
@@ -499,12 +499,12 @@ const char* vala_catch_clause_get_clabel_name (ValaCatchClause* self) {
 
 
 void vala_catch_clause_set_clabel_name (ValaCatchClause* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp2_;
+	const char* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_clabel_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_clabel_name = (g_free (self->priv->_clabel_name), NULL), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_clabel_name = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_clabel_name = (g_free (self->priv->_clabel_name), NULL), _tmp2_);
 }
 
 
