@@ -265,23 +265,23 @@ static void _g_list_free_vala_code_node_unref (GList* self) {
  * Specifies the exceptions that can be thrown by this node or a child node
  */
 GeeList* vala_code_node_get_error_types (ValaCodeNode* self) {
-	GeeList* _tmp4;
+	GeeList* _tmp4_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->_error_types != NULL) {
-		GeeList* _tmp0;
-		_tmp0 = NULL;
-		return (_tmp0 = self->priv->_error_types, (_tmp0 == NULL) ? NULL : gee_collection_object_ref (_tmp0));
+		GeeList* _tmp0_;
+		_tmp0_ = NULL;
+		return (_tmp0_ = self->priv->_error_types, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
 	}
 	if (vala_code_node__empty_type_list == NULL) {
-		GeeList* _tmp3;
-		GeeArrayList* _tmp2;
-		_tmp3 = NULL;
-		_tmp2 = NULL;
-		vala_code_node__empty_type_list = (_tmp3 = (GeeList*) gee_read_only_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, (GeeList*) (_tmp2 = gee_array_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal))), (vala_code_node__empty_type_list == NULL) ? NULL : (vala_code_node__empty_type_list = (gee_collection_object_unref (vala_code_node__empty_type_list), NULL)), _tmp3);
-		(_tmp2 == NULL) ? NULL : (_tmp2 = (gee_collection_object_unref (_tmp2), NULL));
+		GeeList* _tmp3_;
+		GeeArrayList* _tmp2_;
+		_tmp3_ = NULL;
+		_tmp2_ = NULL;
+		vala_code_node__empty_type_list = (_tmp3_ = (GeeList*) gee_read_only_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, (GeeList*) (_tmp2_ = gee_array_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal))), (vala_code_node__empty_type_list == NULL) ? NULL : (vala_code_node__empty_type_list = (gee_collection_object_unref (vala_code_node__empty_type_list), NULL)), _tmp3_);
+		(_tmp2_ == NULL) ? NULL : (_tmp2_ = (gee_collection_object_unref (_tmp2_), NULL));
 	}
-	_tmp4 = NULL;
-	return (_tmp4 = vala_code_node__empty_type_list, (_tmp4 == NULL) ? NULL : gee_collection_object_ref (_tmp4));
+	_tmp4_ = NULL;
+	return (_tmp4_ = vala_code_node__empty_type_list, (_tmp4_ == NULL) ? NULL : gee_collection_object_ref (_tmp4_));
 }
 
 
@@ -293,9 +293,9 @@ void vala_code_node_add_error_type (ValaCodeNode* self, ValaDataType* error_type
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (error_type != NULL);
 	if (self->priv->_error_types == NULL) {
-		GeeList* _tmp0;
-		_tmp0 = NULL;
-		self->priv->_error_types = (_tmp0 = (GeeList*) gee_array_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal), (self->priv->_error_types == NULL) ? NULL : (self->priv->_error_types = (gee_collection_object_unref (self->priv->_error_types), NULL)), _tmp0);
+		GeeList* _tmp0_;
+		_tmp0_ = NULL;
+		self->priv->_error_types = (_tmp0_ = (GeeList*) gee_array_list_new (VALA_TYPE_DATA_TYPE, (GBoxedCopyFunc) vala_code_node_ref, vala_code_node_unref, g_direct_equal), (self->priv->_error_types == NULL) ? NULL : (self->priv->_error_types = (gee_collection_object_unref (self->priv->_error_types), NULL)), _tmp0_);
 	}
 	gee_collection_add ((GeeCollection*) self->priv->_error_types, error_type);
 	vala_code_node_set_parent_node ((ValaCodeNode*) error_type, self);
@@ -406,10 +406,10 @@ ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* nam
 		GList* a_it;
 		a_collection = self->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* _tmp1;
+			ValaAttribute* _tmp1_;
 			ValaAttribute* a;
-			_tmp1 = NULL;
-			a = (_tmp1 = (ValaAttribute*) a_it->data, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1));
+			_tmp1_ = NULL;
+			a = (_tmp1_ = (ValaAttribute*) a_it->data, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_));
 			{
 				if (_vala_strcmp0 (vala_attribute_get_name (a), name) == 0) {
 					return a;
@@ -429,20 +429,20 @@ ValaAttribute* vala_code_node_get_attribute (ValaCodeNode* self, const char* nam
  */
 static char* vala_code_node_real_to_string (ValaCodeNode* self) {
 	GString* str;
-	const char* _tmp1;
-	char* _tmp2;
+	const char* _tmp1_;
+	char* _tmp2_;
 	g_return_val_if_fail (self != NULL, NULL);
 	str = g_string_new ("");
 	g_string_append (str, "/* ");
 	if (self->priv->_source_reference != NULL) {
-		char* _tmp0;
-		_tmp0 = NULL;
-		g_string_append (g_string_append (str, "@"), _tmp0 = vala_source_reference_to_string (self->priv->_source_reference));
-		_tmp0 = (g_free (_tmp0), NULL);
+		char* _tmp0_;
+		_tmp0_ = NULL;
+		g_string_append (g_string_append (str, "@"), _tmp0_ = vala_source_reference_to_string (self->priv->_source_reference));
+		_tmp0_ = (g_free (_tmp0_), NULL);
 	}
-	_tmp1 = NULL;
-	_tmp2 = NULL;
-	return (_tmp2 = (_tmp1 = g_string_append (str, " */")->str, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), (str == NULL) ? NULL : (str = (g_string_free (str, TRUE), NULL)), _tmp2);
+	_tmp1_ = NULL;
+	_tmp2_ = NULL;
+	return (_tmp2_ = (_tmp1_ = g_string_append (str, " */")->str, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), (str == NULL) ? NULL : (str = (g_string_free (str, TRUE), NULL)), _tmp2_);
 }
 
 
@@ -474,12 +474,12 @@ void vala_code_node_get_used_variables (ValaCodeNode* self, GeeCollection* colle
 
 
 char* vala_code_node_get_temp_name (ValaCodeNode* self) {
-	char* _tmp0;
-	char* _tmp1;
+	char* _tmp0_;
+	char* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp0 = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = g_strconcat (".", _tmp0 = g_strdup_printf ("%i", vala_code_node_last_temp_nr = vala_code_node_last_temp_nr + 1), NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+	_tmp0_ = NULL;
+	_tmp1_ = NULL;
+	return (_tmp1_ = g_strconcat (".", _tmp0_ = g_strdup_printf ("%i", vala_code_node_last_temp_nr = vala_code_node_last_temp_nr + 1), NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
 }
 
 
@@ -502,12 +502,12 @@ ValaSourceReference* vala_code_node_get_source_reference (ValaCodeNode* self) {
 
 
 void vala_code_node_set_source_reference (ValaCodeNode* self, ValaSourceReference* value) {
-	ValaSourceReference* _tmp2;
-	ValaSourceReference* _tmp1;
+	ValaSourceReference* _tmp2_;
+	ValaSourceReference* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_source_reference = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_source_reference_ref (_tmp1)), (self->priv->_source_reference == NULL) ? NULL : (self->priv->_source_reference = (vala_source_reference_unref (self->priv->_source_reference), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_source_reference = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_source_reference_ref (_tmp1_)), (self->priv->_source_reference == NULL) ? NULL : (self->priv->_source_reference = (vala_source_reference_unref (self->priv->_source_reference), NULL)), _tmp2_);
 }
 
 
@@ -524,28 +524,28 @@ ValaCCodeNode* vala_code_node_get_ccodenode (ValaCodeNode* self) {
 
 
 void vala_code_node_set_ccodenode (ValaCodeNode* self, ValaCCodeNode* value) {
-	gboolean _tmp1;
-	ValaCCodeNode* _tmp5;
-	ValaCCodeNode* _tmp4;
+	gboolean _tmp1_;
+	ValaCCodeNode* _tmp5_;
+	ValaCCodeNode* _tmp4_;
 	g_return_if_fail (self != NULL);
-	_tmp1 = FALSE;
+	_tmp1_ = FALSE;
 	if (value != NULL) {
-		_tmp1 = self->priv->_source_reference != NULL;
+		_tmp1_ = self->priv->_source_reference != NULL;
 	} else {
-		_tmp1 = FALSE;
+		_tmp1_ = FALSE;
 	}
-	if (_tmp1) {
-		ValaCCodeLineDirective* _tmp3;
-		char* _tmp2;
-		_tmp3 = NULL;
-		_tmp2 = NULL;
-		vala_ccode_node_set_line (value, _tmp3 = vala_ccode_line_directive_new (_tmp2 = g_path_get_basename (vala_source_file_get_filename (vala_source_reference_get_file (self->priv->_source_reference))), vala_source_reference_get_first_line (self->priv->_source_reference)));
-		(_tmp3 == NULL) ? NULL : (_tmp3 = (vala_ccode_node_unref (_tmp3), NULL));
-		_tmp2 = (g_free (_tmp2), NULL);
+	if (_tmp1_) {
+		ValaCCodeLineDirective* _tmp3_;
+		char* _tmp2_;
+		_tmp3_ = NULL;
+		_tmp2_ = NULL;
+		vala_ccode_node_set_line (value, _tmp3_ = vala_ccode_line_directive_new (_tmp2_ = g_path_get_basename (vala_source_file_get_filename (vala_source_reference_get_file (self->priv->_source_reference))), vala_source_reference_get_first_line (self->priv->_source_reference)));
+		(_tmp3_ == NULL) ? NULL : (_tmp3_ = (vala_ccode_node_unref (_tmp3_), NULL));
+		_tmp2_ = (g_free (_tmp2_), NULL);
 	}
-	_tmp5 = NULL;
-	_tmp4 = NULL;
-	self->priv->_ccodenode = (_tmp5 = (_tmp4 = value, (_tmp4 == NULL) ? NULL : vala_ccode_node_ref (_tmp4)), (self->priv->_ccodenode == NULL) ? NULL : (self->priv->_ccodenode = (vala_ccode_node_unref (self->priv->_ccodenode), NULL)), _tmp5);
+	_tmp5_ = NULL;
+	_tmp4_ = NULL;
+	self->priv->_ccodenode = (_tmp5_ = (_tmp4_ = value, (_tmp4_ == NULL) ? NULL : vala_ccode_node_ref (_tmp4_)), (self->priv->_ccodenode == NULL) ? NULL : (self->priv->_ccodenode = (vala_ccode_node_unref (self->priv->_ccodenode), NULL)), _tmp5_);
 }
 
 
@@ -574,15 +574,15 @@ void vala_code_node_set_error (ValaCodeNode* self, gboolean value) {
 
 
 gboolean vala_code_node_get_tree_can_fail (ValaCodeNode* self) {
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	g_return_val_if_fail (self != NULL, FALSE);
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (self->priv->_error_types != NULL) {
-		_tmp0 = gee_collection_get_size ((GeeCollection*) self->priv->_error_types) > 0;
+		_tmp0_ = gee_collection_get_size ((GeeCollection*) self->priv->_error_types) > 0;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	return _tmp0;
+	return _tmp0_;
 }
 
 
