@@ -1265,7 +1265,7 @@ static void vala_switch_statement_real_replace_expression (ValaCodeNode* base, V
 
 static gboolean vala_switch_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaSwitchStatement * self;
-	gboolean _tmp2;
+	gboolean _tmp2_;
 	self = (ValaSwitchStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -1276,13 +1276,13 @@ static gboolean vala_switch_statement_real_check (ValaCodeNode* base, ValaSemant
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		return FALSE;
 	}
-	_tmp2 = FALSE;
+	_tmp2_ = FALSE;
 	if (!vala_data_type_compatible (vala_expression_get_value_type (vala_switch_statement_get_expression (self)), analyzer->uint64_type)) {
-		_tmp2 = !vala_data_type_compatible (vala_expression_get_value_type (vala_switch_statement_get_expression (self)), analyzer->string_type);
+		_tmp2_ = !vala_data_type_compatible (vala_expression_get_value_type (vala_switch_statement_get_expression (self)), analyzer->string_type);
 	} else {
-		_tmp2 = FALSE;
+		_tmp2_ = FALSE;
 	}
-	if (_tmp2) {
+	if (_tmp2_) {
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_switch_statement_get_expression (self)), "Integer or string expression expected");
 		vala_code_node_set_error ((ValaCodeNode*) self, TRUE);
 		return FALSE;
@@ -1309,12 +1309,12 @@ ValaExpression* vala_switch_statement_get_expression (ValaSwitchStatement* self)
 
 
 void vala_switch_statement_set_expression (ValaSwitchStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp2_;
+	ValaExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_expression = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)), _tmp2_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_expression, (ValaCodeNode*) self);
 }
 
