@@ -1258,12 +1258,12 @@ ValaExpression* vala_typecheck_get_expression (ValaTypeCheck* self) {
 
 
 void vala_typecheck_set_expression (ValaTypeCheck* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp2_;
+	ValaExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_expression = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_expression = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_expression == NULL) ? NULL : (self->priv->_expression = (vala_code_node_unref (self->priv->_expression), NULL)), _tmp2_);
 }
 
 
@@ -1274,12 +1274,12 @@ ValaDataType* vala_typecheck_get_type_reference (ValaTypeCheck* self) {
 
 
 void vala_typecheck_set_type_reference (ValaTypeCheck* self, ValaDataType* value) {
-	ValaDataType* _tmp2;
-	ValaDataType* _tmp1;
+	ValaDataType* _tmp2_;
+	ValaDataType* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_data_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_data_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_data_type == NULL) ? NULL : (self->priv->_data_type = (vala_code_node_unref (self->priv->_data_type), NULL)), _tmp2_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_data_type, (ValaCodeNode*) self);
 }
 
